-- name: [CS] Bolo
-- description: KABLOOEY! (Requires Character Select!)

--[[
    API Documentation for Character Select can be found below:
    https://github.com/Squishy6094/character-select-coop/wiki/API-Documentation

    Use this if you're curious on how anything here works >v<
	(This is an edited version of the Template File by Squishy)
]]

local TEXT_MOD_NAME = "[CS] BOLO"

-- Stops mod from loading if Character Select isn't on
if not _G.charSelectExists then
    djui_popup_create("\\#ffffdc\\\n"..TEXT_MOD_NAME.."\nRequires the Character Select Mod\nto use as a Library!\n\nPlease turn on the Character Select Mod\nand Restart the Room!", 6)
    return 0
end

local E_MODEL_BOLO = smlua_model_util_get_id("bolo_geo") -- Located in "actors"

local BOLO_ICON = get_texture_info("BoloIcon") -- Located in "textures"

-- All Located in "actors"
local CAPTABLE_BOLO = {
   normal = smlua_model_util_get_id("bolo_cap_geo"),
   wing = smlua_model_util_get_id("bolo_cap_wing_geo"),
   metal = smlua_model_util_get_id("bolo_cap_metal_geo"),
   metalWing = smlua_model_util_get_id("bolo_cap_metal_wing_geo"),
}

local VOICETABLE_BOLO = {
    [CHAR_SOUND_OKEY_DOKEY] = '0A - 000C - Okey Dokey.ogg', -- Starting game
	[CHAR_SOUND_LETS_A_GO] = '08 - 001A - Lets a go.ogg', -- Starting level
	[CHAR_SOUND_PUNCH_YAH] = '08 - 0002 - Yah.ogg', -- Punch 1
	[CHAR_SOUND_PUNCH_WAH] = '08 - 0007 - Wah 02.ogg', -- Punch 2
	[CHAR_SOUND_PUNCH_HOO] = '0A - 000A - Hoo.ogg', -- Punch 3
	[CHAR_SOUND_YAH_WAH_HOO] = {'0A - 0009 - Yah.ogg', '08 - 0001 - Wah.ogg', '08 - 0000 - Oh.ogg'}, -- First/Second jump sounds
	[CHAR_SOUND_HOOHOO] = '0A - 0001 - Hoohoo.ogg', -- Third jump sound
	[CHAR_SOUND_YAHOO_WAHA_YIPPEE] = {'08 - 0018 - Wahah.ogg', '08 - 0018 - Wahah.ogg', '08 - 0004 - Yahoo.ogg'}, -- Triple jump sounds
	[CHAR_SOUND_UH] = '08 - 0005 - Uhn 02.ogg', -- Wall bonk
	[CHAR_SOUND_UH2] = '0A - 0006 - Uhn.ogg', -- Landing after long jump
	[CHAR_SOUND_UH2_2] = '0A - 0006 - Uhn.ogg', -- Same sound as UH2; jumping onto ledge
	[CHAR_SOUND_HAHA] = '08 - 0003 - Haha.ogg', -- Landing triple jump
	[CHAR_SOUND_YAHOO] = '08 - 0004 - Yahoo.ogg', -- Long jump
	[CHAR_SOUND_DOH] = '08 - 0010 - Doh.ogg', -- Long jump wall bonk
	[CHAR_SOUND_WHOA] = '08 - 0008 - Woah.ogg', -- Grabbing ledge
	[CHAR_SOUND_EEUH] = '08 - 0009 - Ledge Climb.ogg', -- Climbing over ledge
	[CHAR_SOUND_WAAAOOOW] = '0A - 0000 - Wahhh.ogg', -- Falling a long distance
	[CHAR_SOUND_TWIRL_BOUNCE] = '08 - 0014 - Boing.ogg', -- Bouncing off of a flower spring
	[CHAR_SOUND_GROUND_POUND_WAH] = '0A - 0002 - Ooh.ogg',
	[CHAR_SOUND_HRMM] = '08 - 0009 - Ledge Climb.ogg', -- Lifting something
	[CHAR_SOUND_HERE_WE_GO] = '08 - 000C - Here we go.ogg', -- Star get
	[CHAR_SOUND_SO_LONGA_BOWSER] = '08 - 0016 - So long, Bowser.ogg', -- Throwing Bowser
--DAMAGE
	[CHAR_SOUND_ATTACKED] = '08 - 000A - Lose Health.ogg', -- Damaged
	[CHAR_SOUND_PANTING] = 'Silent.ogg', -- Low health
	[CHAR_SOUND_ON_FIRE] = '0A - 0005 - Hot, hot, hot.ogg', -- Burned
--SLEEP SOUNDS
	[CHAR_SOUND_IMA_TIRED] = 'Silent.ogg', -- Mario feeling tired
	[CHAR_SOUND_YAWNING] = 'Silent.ogg', -- Mario yawning before he sits down to sleep
	[CHAR_SOUND_SNORING1] = 'Silent.ogg', -- Snore Inhale
	[CHAR_SOUND_SNORING2] = 'Silent.ogg', -- Exhale
	[CHAR_SOUND_SNORING3] = 'Silent.ogg', -- Sleep talking / mumbling
--COUGHING (USED IN THE GAS MAZE)
	[CHAR_SOUND_COUGHING1] = 'Silent.ogg', -- Cough take 1
	[CHAR_SOUND_COUGHING2] = 'Silent.ogg', -- Cough take 2
	[CHAR_SOUND_COUGHING3] = 'Silent.ogg', -- Cough take 3
--DEATH
	[CHAR_SOUND_DYING] = '0A - 0004 - Uhh Ooph.ogg', -- Dying from damage
	[CHAR_SOUND_DROWNING] = '0A - 000D - Drowning.ogg', -- Running out of air underwater
	[CHAR_SOUND_MAMA_MIA] = '0A - 000B - Mamma Mia.ogg', -- Booted out of level
}

local PALETTE_BOLO = {
    [PANTS]  = "242424",
    [SHIRT]  = "FFFFFF",
    [GLOVES] = "905028",
    [SHOES]  = "242424",
    [HAIR]   = "44578C",
    [SKIN]   = "DB9A5E",
    [CAP]    = "F7E626",
	[EMBLEM] = "242424"
}

local HM_BOLO= {
    label = {
        left = get_texture_info("BoloHL"),
        right = get_texture_info("BoloHR"),
    },
    pie = {
        [1] = get_texture_info("BoloH7"),
        [2] = get_texture_info("BoloH6"),
        [3] = get_texture_info("BoloH5"),
        [4] = get_texture_info("BoloH4"),
        [5] = get_texture_info("BoloH3"),
        [6] = get_texture_info("BoloH2"),
        [7] = get_texture_info("BoloH1"),
        [8] = get_texture_info("BoloH0"),
    }
}

local CSloaded = false
local function on_character_select_load()
    CT_BOLO = _G.charSelect.character_add("Bolo", {"Bolo", "", "KABLOOEY!"}, "Kaktus64", {r = 94, g = 121, b = 194}, E_MODEL_BOLO, CT_BOLO, BOLO_ICON)
	_G.charSelect.character_add_caps(E_MODEL_BOLO, CAPTABLE_BOLO)
    _G.charSelect.character_add_voice(E_MODEL_BOLO, VOICETABLE_BOLO)
    _G.charSelect.character_add_celebration_star(E_MODEL_BOLO, E_MODEL_CUSTOM_STAR, TEX_CUSTOM_STAR_ICON)
    _G.charSelect.character_add_palette_preset(E_MODEL_BOLO, PALETTE_BOLO)
	_G.charSelect.character_add_health_meter(CT_BOLO, HM_BOLO)
    _G.charSelect.character_hook_moveset(CT_BOLO, HOOK_MARIO_UPDATE, HOOK_BEFORE_SET_MARIO_ACTION)

    CSloaded = true
end

local function on_character_sound(m, sound)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_BOLO then return _G.charSelect.voice.sound(m, sound) end
end

local function on_character_snore(m)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_BOLO then return _G.charSelect.voice.snore(m) end
end

hook_event(HOOK_ON_MODS_LOADED, on_character_select_load)
hook_event(HOOK_CHARACTER_SOUND, on_character_sound)
hook_event(HOOK_MARIO_UPDATE, on_character_snore)